@@ -3,8 +3,8 @@
 #' A simple function to perform cross-validated Linear Discriminant Analysis
 #' 
 #' @param Data                 (dataframe) Data dataframe
-#' @param classCol             (numeric)  column number that contains the variable to be predicted
-#' @param selectedCols         (optional) (numeric)  all the columns of data that would be used either as predictor or as feature
+#' @param classCol             (numeric or string)  column number that contains the variable to be predicted
+#' @param selectedCols         (optional) (numeric or string) all the columns of data that would be used either as predictor or as feature
 #' @param extendedResults      (optional) (logical) Return extended results with model  and other metrics
 #' @param SetSeed              (optional) (logical) Whether to setseed or not. use SetSeed to seed the random number generator to get consistent results; 
 #'                             set false only for permutation tests
@@ -85,7 +85,7 @@
 #' @author
 #' Atesh Koul, C'MON unit, Istituto Italiano di Tecnologia
 #'
-#' \email{atesh.koul@@iit.it}
+#' \email{atesh.koul@@gmail.com}
 #' 
 #' 
 #' @references 
@@ -122,9 +122,6 @@ LinearDA <- function(Data,classCol,selectedCols,cvType,nTrainFolds,ntrainTestFol
   if(CV == TRUE & extendedResults==F) warning("No output requested. Please use extendedResults = TRUE to output the model")
   
   
-  if(missing(selectedCols))  selectedCols <- 1:length(names(Data))
-  selectedColNames <- names(Data)[selectedCols]
-  
   # createDataPartition has different behavior for numeric and factor vectors
   # the random sampling is done within the levels of y when y is a factor in an 
   # attempt to balance the class distributions within the splits.
@@ -134,6 +131,36 @@ LinearDA <- function(Data,classCol,selectedCols,cvType,nTrainFolds,ntrainTestFol
   # and sampling is done within these subgroups (see ?createDataPartition for more details)
   # 
   # Make the outcome factor anyways
+  # Modified so that it works even with tibble; force the tibble to be a dataframe
+  # This is not the best way to proceed; Ideally, all the code should be updated 
+  # to work with tibble
+  # make it a bit generic to handle matrices as well along with a warning 
+  permittedDataClass <- c("tbl_df","matrix")
+  if(any(permittedDataClass %in% class(Data))){
+    warning(cat("the data entered is of the class ",class(Data),". Coersing it to be a dataframe. Check results"))
+    Data <- as.data.frame(Data)
+  }
+  
+  # get the classCol name:  in case u enter names of columns, it works anyways
+  # ensures that we have both correct classCol and predictorColNames as the function expects
+  if(is.character(classCol)){
+    predictorColNames <- classCol
+    classCol <- grep(predictorColNames,names(Data))
+  }else    predictorColNames <- names(Data)[classCol]
+  
+  
+  if(missing(selectedCols))  selectedCols <- 1:length(names(Data))
+  
+  # get the features:  in case u enter names of columns, it works anyways
+  ifelse(is.character(selectedCols),selectedColNames <- selectedCols,selectedColNames <- names(Data)[selectedCols])
+  
+  # old way
+  # selectedColNames <- names(Data)[selectedCols]
+  
+  # protection measure if u forgot to put predictor column in the selected list
+  if(!(predictorColNames %in% selectedColNames)) stop("\n Predictor Column name not present in selected column name list")
+  
+  
   Data[,classCol] <- factor(Data[,classCol])
   
   
